import random
import requests
from .letter import Letter
from ..exceptions import NotSetEmail
from ..mail import Mail
from .tempmailplusdomains import TempMailPlusDomains


class TempMailPlus(Mail):
    """
    Class for work with https://tempmail.plus
    """
    def __init__(self, proxy=None):
        super().__init__(proxy)

    def set_email(self, email, domain: TempMailPlusDomains = None):
        """
        Use custom email address with custom domain.

        :param email: Email address.
        :param domain: Domain of email address, set None for random.
        :return: Email address.
        """

        if not domain:
            domain = TempMailPlusDomains[random.choice(TempMailPlusDomains._member_names_)]
        return super()._set_email(email + '@' + domain.value)

    def get_inbox(self):
        if not self._email:
            raise NotSetEmail()

        r = requests.get(f'https://tempmail.plus/api/mails?email={self._email}&limit=100')
        if r.status_code == 200:
            return [Letter(self._email, _letter, self._proxies) for _letter in r.json()['mail_list']]
        return []


import enum


class Counties(enum.Enum):
    AFGHANISTAN = 'AF'
    ALAND_ISLANDS = 'AX'
    ALBANIA = 'AL'
    ALGERIA = 'DZ'
    AMERICAN_SAMOA = 'AS'
    ANDORRA = 'AD'
    ANGOLA = 'AO'
    ANGUILLA = 'AI'
    ANTARCTICA = 'AQ'
    ANTIGUA_BARBUDA = 'AG'
    ARGENTINA = 'AR'
    ARMENIA = 'AM'
    ARUBA = 'AW'
    AUSTRALIA = 'AU'
    AUSTRIA = 'AT'
    AZERBAIJAN = 'AZ'
    BAHAMAS = 'BS'
    BAHRAIN = 'BH'
    BANGLADESH = 'BD'
    BARBADOS = 'BB'
    BELARUS = 'BY'
    BELGIUM = 'BE'
    BELIZE = 'BZ'
    BENIN = 'BJ'
    BERMUDA = 'BM'
    BHUTAN = 'BT'
    BOLIVIA = 'BO'
    BOSNIA_HERZEGOVINA = 'BA'
    BOTSWANA = 'BW'
    BOUVET_ISLAND = 'BV'
    BRAZIL = 'BR'
    BRITISH_INDIAN_OCEAN_TERRITORY = 'IO'
    BRITISH_VIRGIN_ISLANDS = 'VG'
    BRUNEI = 'BN'
    BULGARIA = 'BG'
    BURKINA_FASO = 'BF'
    BURUNDI = 'BI'
    CAMBODIA = 'KH'
    CAMEROON = 'CM'
    CANADA = 'CA'
    CAPE_VERDE = 'CV'
    CARIBBEAN_NETHERLANDS = 'BQ'
    CAYMAN_ISLANDS = 'KY'
    CENTRAL_AFRICAN_REPUBLIC = 'CF'
    CHAD = 'TD'
    CHILE = 'CL'
    CHINA = 'CN'
    CHRISTMAS_ISLAND = 'CX'
    COCOS_KEELING_ISLANDS = 'CC'
    COLOMBIA = 'CO'
    COMOROS = 'KM'
    CONGO_BRAZZAVILLE = 'CG'
    CONGO_KINSHASA = 'CD'
    COOK_ISLANDS = 'CK'
    COSTA_RICA = 'CR'
    COTE_DIVOIRE = 'CI'
    CROATIA = 'HR'
    CUBA = 'CU'
    CURACAO = 'CW'
    CYPRUS = 'CY'
    CZECHIA = 'CZ'
    DENMARK = 'DK'
    DJIBOUTI = 'DJ'
    DOMINICA = 'DM'
    DOMINICAN_REPUBLIC = 'DO'
    ECUADOR = 'EC'
    EGYPT = 'EG'
    EL_SALVADOR = 'SV'
    EQUATORIAL_GUINEA = 'GQ'
    ERITREA = 'ER'
    ESTONIA = 'EE'
    ESWATINI = 'SZ'
    ETHIOPIA = 'ET'
    FALKLAND_ISLANDS = 'FK'
    FAROE_ISLANDS = 'FO'
    FIJI = 'FJ'
    FINLAND = 'FI'
    FRANCE = 'FR'
    FRENCH_GUIANA = 'GF'
    FRENCH_POLYNESIA = 'PF'
    FRENCH_SOUTHERN_TERRITORIES = 'TF'
    GABON = 'GA'
    GAMBIA = 'GM'
    GEORGIA = 'GE'
    GERMANY = 'DE'
    GHANA = 'GH'
    GIBRALTAR = 'GI'
    GREECE = 'GR'
    GREENLAND = 'GL'
    GRENADA = 'GD'
    GUADELOUPE = 'GP'
    GUAM = 'GU'
    GUATEMALA = 'GT'
    GUERNSEY = 'GG'
    GUINEA = 'GN'
    GUINEA_BISSAU = 'GW'
    GUYANA = 'GY'
    HAITI = 'HT'
    HEARD_MCDONALD_ISLANDS = 'HM'
    HONDURAS = 'HN'
    HONG_KONG_SAR_CHINA = 'HK'
    HUNGARY = 'HU'
    ICELAND = 'IS'
    INDIA = 'IN'
    INDONESIA = 'ID'
    IRAN = 'IR'
    IRAQ = 'IQ'
    IRELAND = 'IE'
    ISLE_OF_MAN = 'IM'
    ISRAEL = 'IL'
    ITALY = 'IT'
    JAMAICA = 'JM'
    JAPAN = 'JP'
    JERSEY = 'JE'
    JORDAN = 'JO'
    KAZAKHSTAN = 'KZ'
    KENYA = 'KE'
    KIRIBATI = 'KI'
    KUWAIT = 'KW'
    KYRGYZSTAN = 'KG'
    LAOS = 'LA'
    LATVIA = 'LV'
    LEBANON = 'LB'
    LESOTHO = 'LS'
    LIBERIA = 'LR'
    LIBYA = 'LY'
    LIECHTENSTEIN = 'LI'
    LITHUANIA = 'LT'
    LUXEMBOURG = 'LU'
    MACAO_SAR_CHINA = 'MO'
    MADAGASCAR = 'MG'
    MALAWI = 'MW'
    MALAYSIA = 'MY'
    MALDIVES = 'MV'
    MALI = 'ML'
    MALTA = 'MT'
    MARSHALL_ISLANDS = 'MH'
    MARTINIQUE = 'MQ'
    MAURITANIA = 'MR'
    MAURITIUS = 'MU'
    MAYOTTE = 'YT'
    MEXICO = 'MX'
    MICRONESIA = 'FM'
    MOLDOVA = 'MD'
    MONACO = 'MC'
    MONGOLIA = 'MN'
    MONTENEGRO = 'ME'
    MONTSERRAT = 'MS'
    MOROCCO = 'MA'
    MOZAMBIQUE = 'MZ'
    MYANMAR_BURMA = 'MM'
    NAMIBIA = 'NA'
    NAURU = 'NR'
    NEPAL = 'NP'
    NETHERLANDS = 'NL'
    NEW_CALEDONIA = 'NC'
    NEW_ZEALAND = 'NZ'
    NICARAGUA = 'NI'
    NIGER = 'NE'
    NIGERIA = 'NG'
    NIUE = 'NU'
    NORFOLK_ISLAND = 'NF'
    NORTH_KOREA = 'KP'
    NORTH_MACEDONIA = 'MK'
    NORTHERN_MARIANA_ISLANDS = 'MP'
    NORWAY = 'NO'
    OMAN = 'OM'
    PAKISTAN = 'PK'
    PALAU = 'PW'
    PALESTINIAN_TERRITORIES = 'PS'
    PANAMA = 'PA'
    PAPUA_NEW_GUINEA = 'PG'
    PARAGUAY = 'PY'
    PERU = 'PE'
    PHILIPPINES = 'PH'
    PITCAIRN_ISLANDS = 'PN'
    POLAND = 'PL'
    PORTUGAL = 'PT'
    PUERTO_RICO = 'PR'
    QATAR = 'QA'
    REUNION = 'RE'
    ROMANIA = 'RO'
    RUSSIA = 'RU'
    RWANDA = 'RW'
    SAMOA = 'WS'
    SAN_MARINO = 'SM'
    SAO_TOME_PRINCIPE = 'ST'
    SAUDI_ARABIA = 'SA'
    SENEGAL = 'SN'
    SERBIA = 'RS'
    SEYCHELLES = 'SC'
    SIERRA_LEONE = 'SL'
    SINGAPORE = 'SG'
    SINT_MAARTEN = 'SX'
    SLOVAKIA = 'SK'
    SLOVENIA = 'SI'
    SOLOMON_ISLANDS = 'SB'
    SOMALIA = 'SO'
    SOUTH_AFRICA = 'ZA'
    SOUTH_GEORGIA_SOUTH_SANDWICH_ISLANDS = 'GS'
    SOUTH_KOREA = 'KR'
    SOUTH_SUDAN = 'SS'
    SPAIN = 'ES'
    SRI_LANKA = 'LK'
    ST_BARTHELEMY = 'BL'
    ST_HELENA = 'SH'
    ST_KITTS_NEVIS = 'KN'
    ST_LUCIA = 'LC'
    ST_MARTIN = 'MF'
    ST_PIERRE_MIQUELON = 'PM'
    ST_VINCENT_GRENADINES = 'VC'
    SUDAN = 'SD'
    SURINAME = 'SR'
    SVALBARD_JAN_MAYEN = 'SJ'
    SWEDEN = 'SE'
    SWITZERLAND = 'CH'
    SYRIA = 'SY'
    TAIWAN = 'TW'
    TAJIKISTAN = 'TJ'
    TANZANIA = 'TZ'
    THAILAND = 'TH'
    TIMOR_LESTE = 'TL'
    TOGO = 'TG'
    TOKELAU = 'TK'
    TONGA = 'TO'
    TRINIDAD_TOBAGO = 'TT'
    TUNISIA = 'TN'
    TURKEY = 'TR'
    TURKMENISTAN = 'TM'
    TURKS_CAICOS_ISLANDS = 'TC'
    TUVALU = 'TV'
    US_OUTLYING_ISLANDS = 'UM'
    US_VIRGIN_ISLANDS = 'VI'
    UGANDA = 'UG'
    UKRAINE = 'UA'
    UNITED_ARAB_EMIRATES = 'AE'
    UNITED_KINGDOM = 'GB'
    UNITED_STATES = 'US'
    URUGUAY = 'UY'
    UZBEKISTAN = 'UZ'
    VANUATU = 'VU'
    VATICAN_CITY = 'VA'
    VENEZUELA = 'VE'
    VIETNAM = 'VN'
    WALLIS_FUTUNA = 'WF'
    WESTERN_SAHARA = 'EH'
    YEMEN = 'YE'
    ZAMBIA = 'ZM'
    ZIMBABWE = 'ZW'
